@@ -1,7 +1,7 @@
 
 library("mlt")
 library("eha")
-library("alabama")
+library("survival")
 set.seed(29)
 
 ## ************** Exponential - AFT *********************************
